==> haskell-statevar-1.1.1.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-statevar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: StateVar
version: 1.1.1.0
id: StateVar-1.1.1.0-6SqVHjIDY01BSHlFA5jy8D
key: StateVar-1.1.1.0-6SqVHjIDY01BSHlFA5jy8D
license: BSD3
copyright: Copyright (C) 2014-2015 Edward A. Kmett, 2009-2018 Sven Panne
maintainer: Sven Panne <svenpanne@gmail.com>
homepage: https://github.com/haskell-opengl/StateVar
synopsis: State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.
category: Data
author: Sven Panne and Edward Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.StateVar
abi: 2a3d4c2d2912b2813eb9e262dc48d6d9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/StateVar-1.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/StateVar-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/StateVar-1.1.1.0
hs-libraries: HSStateVar-1.1.1.0-6SqVHjIDY01BSHlFA5jy8D
depends:
    base-4.10.1.0 stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    transformers-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad99cb175fde1a67819ef6519a4015eb
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html: /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statevar-1.1.1.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-statevar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: StateVar
version: 1.1.1.0
id: StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ
key: StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ
license: BSD-3-Clause
copyright: Copyright (C) 2014-2015 Edward A. Kmett, 2009-2018 Sven Panne
maintainer: Sven Panne <svenpanne@gmail.com>
author: Sven Panne and Edward Kmett
homepage: https://github.com/haskell-opengl/StateVar
synopsis: State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.
category: Data
abi: ea1020bdc9b0b2f074c6181c486759e5
exposed: True
exposed-modules:
    Data.StateVar
import-dirs: /usr/lib/ghc-8.4.2/site-local/StateVar-1.1.1.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/StateVar-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/StateVar-1.1.1.0
hs-libraries: HSStateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ
depends:
    base-4.11.1.0 stm-2.4.5.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             stm-2.4.5.0=fc4e40e3aa6203460dfa01934bcd44f0
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
haddock-interfaces: /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html: /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
